@@ -15,6 +15,7 @@ class Protobuf2EnvelopeWrapper(IEnvelopeWrapper):
         self.serializer.dump(arguments, self.message.arguments2)
 
         self.buffer = None
+        self.estimated_length = self.serializer.get_estimated_pending_bytes()
 
     def get_buffer(self):
         if self.buffer is not None:
@@ -34,8 +35,5 @@ class Protobuf2EnvelopeWrapper(IEnvelopeWrapper):
 
         return self.buffer
 
-    def __len__(self):
-        if self.buffer is not None:
-            return len(self.buffer)
-
-        return self.message.ByteSize() + self.serializer.get_estimated_pending_bytes()
+    def __len__(self):      
+        return self.estimated_length
