@@ -4,6 +4,7 @@ import platform
 import socket
 
 import six
+from rook.com_ws.linux_distribution import LinuxDistribution
 
 from rook.config import VersionConfiguration, GitConfig
 from rook import git
@@ -107,7 +108,7 @@ class SystemInformation(Information):
             'os': platform.system,
             'os_version': self._get_os_version,
             # linux distro name on linux, blank otherwise
-            'distro': lambda: platform.system() == 'Linux' and platform.linux_distribution()[0] or '',
+            'distro': lambda: platform.system() == 'Linux' and LinuxDistribution.get_name() or '',
             'arch': platform.machine()
         }
 
@@ -117,7 +118,7 @@ class SystemInformation(Information):
         if system == 'Darwin':
             version = platform.mac_ver()[0]
         elif system == 'Linux':
-            version = platform.linux_distribution()[1]
+            version = LinuxDistribution.get_version()
         elif system == 'Windows':
             version = platform.win32_ver()[0]
         else:
