@@ -117,7 +117,10 @@ class AgentCom(object):
             self._connection.close(1000)
 
         self._thread.join()
-        self._connection = None
+
+        if self._connection is not None:
+            self._connection.close(1000)
+            self._connection = None
 
     def restart(self):
         self.stop()
@@ -135,7 +138,7 @@ class AgentCom(object):
     def send_user_message(self, aug_id, message_id, arguments):
         envelope = Protobuf2EnvelopeWrapper(self.id, aug_id, message_id, arguments)
 
-        self.add_envelope(envelope)
+        return self.add_envelope(envelope)
 
     def add(self, message):
         if self._queue.qsize() >= AgentComConfiguration.MAX_QUEUED_MESSAGES:
@@ -261,16 +264,11 @@ class AgentCom(object):
             routines = [threading.Thread(name="rookout-incoming-thread", target=self._incoming, args=(incoming_client_socket, signal_stop_outgoing_thread)),
                         threading.Thread(name="rookout-outgoing-thread", target=self._outgoing, args=(outgoing_exit_sentinel, signal_stop_incoming_thread))]
 
-            got_initial_augs = self.await_message('InitialAugsCommand')
-
             for routine in routines:
                 routine.daemon = True
                 routine.start()
 
-            if got_initial_augs.wait(AgentComConfiguration.TIMEOUT):
-                logger.info("Finished initialization")
-            else:
-                logger.warning("Timeout waiting for initial augs")
+            logger.info("Finished initialization")
 
             for routine in routines:
                 routine.join()
@@ -321,7 +319,7 @@ class AgentCom(object):
 
     def _incoming(self, stop_socket, on_exit):
         try:
-            while True:
+            while self._running:
                 try:
                     # Poll has no file_descriptor limit (on linux) if available - use it
                     if self.poll_available:
@@ -370,7 +368,7 @@ class AgentCom(object):
             last_ping = time.time()
             self._connection.ping()
 
-            while True:
+            while self._running:
                 envelope_wrapper = None
                 if (time.time() - last_ping) >= AgentComConfiguration.PING_INTERVAL:
                     last_ping = time.time()
