@@ -62,20 +62,28 @@ class Output(object):
             return
 
         def send_msg():
-            msg = AugReportMessage()
-            msg.agent_id = self._id
-            msg.aug_id = aug_id
-            msg.report_id = message_id
-
             if arguments and arguments.size(''):
-                serializer = NamespaceSerializer(config.DumpConfig.STRING_CACHE_USERMESSAGE)
-                serializer.dump(arguments, msg.arguments)
-                for k, v in six.iteritems(serializer.get_string_cache()):
-                    msg.strings_cache[k] = v
+                if config.DumpConfig.PROTOBUF_VERSION_2:
+                    error = self._agent_com.send_user_message(aug_id, message_id, arguments)
+                    if error:
+                        if not isinstance(error, RookError):
+                            error = RookError(error)
+                        UserWarnings.send_warning(error)
+                else:
+                    msg = AugReportMessage()
+                    msg.agent_id = self._id
+                    msg.aug_id = aug_id
+                    msg.report_id = message_id
 
-            error = self._agent_com.add(msg)
-            if error:
-                UserWarnings.send_warning(RookError(error))
+                    serializer = NamespaceSerializer(config.DumpConfig.STRING_CACHE_USERMESSAGE)
+                    serializer.dump(arguments, msg.arguments)
+
+                    for k, v in six.iteritems(serializer.get_string_cache()):
+                        msg.strings_cache[k] = v
+
+                    error = self._agent_com.add(msg)
+                    if error:
+                        UserWarnings.send_warning(RookError(error))
         self._user_message_bucket.do_if_available(send_msg)
 
     LOG_LEVELS = {
