@@ -1,5 +1,8 @@
 import threading
 import time
+
+from rook.com_ws.envelope_wrappers.basic_envelope_wrapper import BasicEnvelopeWrapper
+from rook.com_ws.envelope_wrappers.basic_serialized_envelope_wrapper import BasicSerializedEnvelopeWrapper
 from six.moves.urllib.parse import urlparse
 import certifi
 import ssl
@@ -10,9 +13,9 @@ import websocket
 
 from rook.com_ws.flush_messages_event import FlushMessagesEvent
 from rook.com_ws.singlethread.network_event_loop import NetworkEventLoop
-from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, RookMessageSizeExceeded, RookMissingToken
-import rook.com_ws.socketpair_compat  # do not remove - adds socket.socketpair on Windows lgtm[py/unused-import]
-
+from rook.exceptions import RookCommunicationException, RookInvalidToken, RookDependencyConflict, \
+    RookMissingToken, RookQueueSizeExceeded
+from rook.com_ws.envelope_wrappers.protobuf_2_envelope_wrapper import Protobuf2EnvelopeWrapper
 
 try:
     from websocket import WebSocketBadStatusException # This is used to make sure we have the right version lgtm[py/unused-import]
@@ -67,7 +70,9 @@ class AgentCom(object):
 
         self._loop = None
         self._connection = None
+        # Queue hold outgoing messages wrapped with IEnvelopeWrapper
         self._queue = selectable_queue.SelectableQueue()
+        self._queue.messages_length = 0
 
         self._running = True
 
@@ -118,15 +123,25 @@ class AgentCom(object):
         self._labels = labels or {}
         self._tags = tags or []
 
+    def send_user_message(self, aug_id, message_id, arguments):
+        envelope = Protobuf2EnvelopeWrapper(self.id, aug_id, message_id, arguments)
+
+        self.add_envelope(envelope)
+
     def add(self, message):
         if self._queue.qsize() >= AgentComConfiguration.MAX_QUEUED_MESSAGES:
             return None
 
-        packaged_message = wrap_in_envelope(message)
-        if len(packaged_message) > AgentComConfiguration.MAX_MESSAGE_LENGTH:
-            return RookMessageSizeExceeded(len(packaged_message), AgentComConfiguration.MAX_MESSAGE_LENGTH)
+        envelope = BasicSerializedEnvelopeWrapper(message)
+        return self.add_envelope(envelope)
 
-        self._queue.put(packaged_message)
+    def add_envelope(self, envelope):
+        if len(envelope) + self._queue.messages_length > AgentComConfiguration.MAX_QUEUE_MESSAGES_LENGTH:
+            return RookQueueSizeExceeded(len(envelope), self._queue.messages_length,
+                                         AgentComConfiguration.MAX_QUEUE_MESSAGES_LENGTH)
+
+        self._queue.messages_length += len(envelope)
+        self._queue.put(envelope)
         return None
 
     def is_queue_full(self):
@@ -207,14 +222,17 @@ class AgentCom(object):
                     self._loop.stop()
                     self._loop = None
                 self._loop = NetworkEventLoop(self._connection, self._queue, self._handle_incoming_message, got_initial_augs_event)
-                self._loop.run_until_stopped()
+                try:
+                    self._loop.run_until_stopped()
+                except Exception as exc:
+                    logger.exception("network loop stopped", exc)
 
             if self._running:
                 logger.debug("Reconnecting")
 
     def flush_all_messages(self):
         flush_event = FlushMessagesEvent()
-        self._queue.put(flush_event)
+        self._queue.put(BasicEnvelopeWrapper(flush_event))
         flush_event.event.wait(AgentComConfiguration.FLUSH_TIMEOUT)
 
     def _create_connection(self):
