@@ -68,6 +68,10 @@ class NetworkEventLoop(object):
                             logger.debug("Reading msg - socket disconnected")
                             break
 
+                        if len(msg) > AgentComConfiguration.AGENT_COM_INCOMING_MAX_MESSAGE_SIZE:
+                            logger.error("message length (%d) exceed max size", msg)
+                            continue
+
                         envelope = envelope_pb.Envelope()
                         envelope.ParseFromString(msg)
                         self._handle_incoming_msg(envelope)
@@ -76,17 +80,19 @@ class NetworkEventLoop(object):
                     break
             # queue appeared in rlist, means there's a new message to send
             if self._queue in rlist:
-                msg = None
+                wrapped_envelope = None
                 try:
-                    msg = self._queue.get()
+                    wrapped_envelope = self._queue.get()
+                    msg = wrapped_envelope.get_buffer()
                     if isinstance(msg, FlushMessagesEvent):
                         msg.event.set()
                         continue
                     self._connection.send_binary(msg)
                 except (socket.error, websocket.WebSocketConnectionClosedException):
-                    if msg is not None:
-                        self._queue.put(msg)
+                    if wrapped_envelope is not None:
+                        self._queue.put(wrapped_envelope)
                     break
+                self._queue.messages_length - len(wrapped_envelope)
 
     def stop(self):
         self._running = False
