@@ -18,10 +18,6 @@ class VersionConfiguration(object):
     COMMIT = "CommitGoesHere"
 
 
-class ProtobufConfiguration(object):
-    NAMESPACE_SERIALIZER_DUMPING = r""
-
-
 class ControllerAddress(object):
     HOST = 'wss://control.rookout.com'
     PORT = 443
@@ -30,6 +26,7 @@ class ControllerAddress(object):
 class AgentComConfiguration(object):
     COMMAND_THREAD_NAME = "rookout_agent_com"
     MAX_MESSAGE_LENGTH = 1024 * 1024
+    MAX_QUEUE_MESSAGES_LENGTH = 15 * 1024 * 1024
     BACK_OFF = 0.2
     MAX_SLEEP = 60
     TIMEOUT = 3
@@ -39,6 +36,7 @@ class AgentComConfiguration(object):
     RESET_BACKOFF_TIMEOUT = 3*60.0
     FLUSH_TIMEOUT = 3
     MAX_QUEUED_MESSAGES = 100
+    AGENT_COM_INCOMING_MAX_MESSAGE_SIZE = 500 * 1024
 
 
 class OutputWsConfiguration(object):
@@ -79,17 +77,28 @@ class ShutdownConfig(object):
 
 class DumpConfig(object):
     STRING_CACHE_USERMESSAGE = False
+    PROTOBUF_VERSION_2 = False
 
 
 def update_config(new_config):
+    from rook.logger import logger
+
     try:
         for key, val in six.iteritems(new_config):
             if key == 'PYTHON_StringCache_UserMessage':
+                logger.debug("Updating StringCache_UserMessage value to: " + str(val in _TRUE_VALUES))
                 DumpConfig.STRING_CACHE_USERMESSAGE = val in _TRUE_VALUES
                 continue
-    except:
-        try:
-            from rook.logger import logger
-            logger.exception("Failed to update configuration: " + str(new_config))
-        except:  # lgtm[py/catch-base-exception]
-            pass
+            if key == 'PYTHON_PROTOBUF_VERSION_2':
+                import os
+                protobuf_2_env_var = os.environ.get('ROOKOUT_Protobuf_Version2')
+
+                if protobuf_2_env_var:
+                    logger.debug("Updating ROOKOUT_Protobuf_Version2 value to: " + str(protobuf_2_env_var in _TRUE_VALUES))
+                    DumpConfig.PROTOBUF_VERSION_2 = protobuf_2_env_var in _TRUE_VALUES
+                else:
+                    logger.debug("Updating ROOKOUT_Protobuf_Version2 value to: " + str(val in _TRUE_VALUES))
+                    DumpConfig.PROTOBUF_VERSION_2 = val in _TRUE_VALUES
+                continue
+    except BaseException:
+        logger.exception("Failed to update configuration: " + str(new_config))
