@@ -51,7 +51,8 @@ class WebHookRetryLevelException(Exception):
 
 class RookSettingBreakpointError(RookException):
     def __init__(self, msg):
-        super(RookSettingBreakpointError, self).__init__("Failed to set breakpoint in this location %s" % msg, {'msg': msg})
+        super(RookSettingBreakpointError, self).__init__("Failed to set breakpoint in this location %s" % msg,
+                                                         {'msg': msg})
 
 
 class RookInvalidArithmeticPath(RookInputException):
@@ -206,6 +207,18 @@ class RookRuleRateLimited(RookException):
                                                   "For more information: https://docs.rookout.com/docs/breakpoints-tasks.html#rate-limiting")
 
 
+class RookGlobalRuleRateLimited(RookException):
+    def __init__(self):
+        super(RookGlobalRuleRateLimited, self).__init__("Breakpoint was disabled due to global-rate-limiting. "
+                                                        "For more information: https://docs.rookout.com/docs/breakpoints-tasks.html#rate-limiting")
+
+
+class RookInvalidRateLimitConfiguration(RookException):
+    def __init__(self, config):
+        super(RookInvalidRateLimitConfiguration, self).__init__("Got an invalid value for the rate limit. (got " +
+                                                                config + ") expected XX/YY or XX\\YY, where XX < YY")
+
+
 class RookRuleMaxExecutionTimeReached(RookException):
     def __init__(self):
         super(RookRuleMaxExecutionTimeReached, self).__init__(
@@ -326,3 +339,13 @@ class RookMessageSizeExceeded(RookException):
                                                       (message_size, max_message_size),
                                                       {'message_size': message_size,
                                                        'max_message_size': max_message_size})
+
+
+class RookQueueSizeExceeded(RookException):
+    def __init__(self, message_size, queue_size, max_queue_size):
+        super(RookQueueSizeExceeded, self).__init__("Message size of %d would exceed max queue size of %d. "
+                                                      "Consider changing the depth of collection and trying again." %
+                                                      (message_size, max_queue_size),
+                                                      {'message_size': message_size,
+                                                       'queue_messages_length': queue_size,
+                                                       'max_queue_messages_length': max_queue_size})
