@@ -1,6 +1,6 @@
 from .namespace import Namespace
 from .collection_namespace import ListNamespace
-from .container_namespace import ContainerNamespace
+from .traceback_namespace import TracebackNamespace
 
 
 class StackNamespace(Namespace):
@@ -30,26 +30,7 @@ class StackNamespace(Namespace):
         else:
             depth = self.DEFAULT_TRACEBACK_DEPTH
 
-        result = []
-
-        current_frame = self._frame
-
-        for i in range(depth):
-            module = current_frame.module()
-
-            result.append(ContainerNamespace({
-                'module': module,
-                'filename': current_frame.filename(),
-                'line': current_frame.line(),
-                'function': current_frame.function()
-            }))
-
-            current_frame = current_frame.f_back()
-
-            if not current_frame:
-                break
-
-        return ListNamespace(result)
+        return TracebackNamespace(self._frame, depth)
 
     def frames(self, args=None):
         if args:
