@@ -28,12 +28,11 @@ class TracebackNamespace(Namespace):
 
         return current_frame
 
-    def dump(self, traceback_frames_holder, get_string_index_in_cache=None):
+    def dump(self, traceback_frames_holder, get_string_index_in_cache=None, increase_pending_size=lambda _size: None):
         """
         Dump traceback frames to given 'traceback_frames_holder'.
         It's the caller responsibility to set the variant type.
         """
-
         current_frame = self._frame
 
         for i in range(self._depth):
@@ -48,6 +47,7 @@ class TracebackNamespace(Namespace):
                 frame.filename_index_in_cache = get_string_index_in_cache(current_frame.filename().obj if current_frame.filename().obj is not None else "unavailable")
                 frame.name_index_in_cache = get_string_index_in_cache(current_frame.function().obj if current_frame.function().obj is not None else "unavailable")
                 frame.module_index_in_cache = get_string_index_in_cache(current_frame.module().obj if current_frame.module().obj is not None else "unavailable")
+                increase_pending_size(11)
 
             traceback_frames_holder.append(frame)
 
